==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-file-associations/lxqt-config-file-associations_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../../../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>アプリケーションの関連付け</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>このファイルを開くアプリケーション:</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>JPEGを扱うアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="124"/>
        <location filename="../../../applicationchooser.ui" line="129"/>
        <location filename="../../../applicationchooser.ui" line="139"/>
        <location filename="../../../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>新しいサブアイテム</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="135"/>
        <location filename="../../../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>その他のアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>%1 を扱うアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>アプリケーションが見つかりませんでした</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../../../mimetypeviewer.cpp" line="157"/>
        <location filename="../../../mimetypeviewer.cpp" line="208"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.cpp" line="204"/>
        <source>&amp;Change...</source>
        <translation>変更(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.cpp" line="209"/>
        <source>&amp;Choose...</source>
        <translation>選択(&amp;C)</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>ファイルの関連付け</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>デフォルトのアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>選択(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>パターン</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation>*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIMEタイプ</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-config/lxqt-config-file-associations/lxqt-config-file-associations_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../../../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>アプリケーションの関連付け</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>このファイルを開くアプリケーション:</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>JPEGを扱うアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="124"/>
        <location filename="../../../applicationchooser.ui" line="129"/>
        <location filename="../../../applicationchooser.ui" line="139"/>
        <location filename="../../../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>新しいサブアイテム</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.ui" line="135"/>
        <location filename="../../../applicationchooser.cpp" line="113"/>
        <source>Other applications</source>
        <translation>その他のアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.cpp" line="114"/>
        <source>Applications that handle %1</source>
        <translation>%1 を扱うアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../applicationchooser.cpp" line="151"/>
        <source>No applications found</source>
        <translation>アプリケーションが見つかりませんでした</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../../../mimetypeviewer.cpp" line="156"/>
        <location filename="../../../mimetypeviewer.cpp" line="207"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.cpp" line="203"/>
        <source>&amp;Change...</source>
        <translation>変更(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.cpp" line="208"/>
        <source>&amp;Choose...</source>
        <translation>選択(&amp;C)...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>ファイルの関連付け</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="56"/>
        <source>Default application</source>
        <translation>デフォルトのアプリケーション</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="68"/>
        <source>&amp;Choose...</source>
        <translation>選択(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="117"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="124"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="144"/>
        <source>Patterns</source>
        <translation>パターン</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="156"/>
        <source>*.txt *.xml</source>
        <translation>*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="173"/>
        <source>MIME type</source>
        <translation>MIMEタイプ</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="191"/>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location filename="../../../mimetypeviewer.ui" line="198"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
</context>
</TS>
